==> blancoNLpackGenerator-0.0.95-src.zip: src/blanco/xliff/util/task/valueobject/BlancoXliffUtilChangeProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.util.task.valueobject;

/**
 * NX [BlancoXliffUtilChangeProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoXliffUtilChangeProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [targetfile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C
     */
    private String fTargetfile;

    /**
     * tB[h [sourcefile]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@CB
     */
    private String fSourcefile;

    /**
     * tB[h [settargetifnotexist]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * target ꍇ target Zbg邩ǂB
     */
    private boolean fSettargetifnotexist = false;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [targetfile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C
     *
     * @param argTargetfile tB[h[targetfile]Ɋi[l
     */
    public void setTargetfile(final String argTargetfile) {
        fTargetfile = argTargetfile;
    }

    /**
     * tB[h[targetfile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C
     *
     * @return tB[h[targetfile]Ɋi[Ăl
     */
    public String getTargetfile() {
        return fTargetfile;
    }

    /**
     * tB[h [sourcefile]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@CB
     *
     * @param argSourcefile tB[h[sourcefile]Ɋi[l
     */
    public void setSourcefile(final String argSourcefile) {
        fSourcefile = argSourcefile;
    }

    /**
     * tB[h[sourcefile]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ͑Ώۂ XLIFF (*.xlf) t@CB
     *
     * @return tB[h[sourcefile]Ɋi[Ăl
     */
    public String getSourcefile() {
        return fSourcefile;
    }

    /**
     * tB[h [settargetifnotexist]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * target ꍇ target Zbg邩ǂB
     *
     * @param argSettargetifnotexist tB[h[settargetifnotexist]Ɋi[l
     */
    public void setSettargetifnotexist(final boolean argSettargetifnotexist) {
        fSettargetifnotexist = argSettargetifnotexist;
    }

    /**
     * tB[h[settargetifnotexist]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * target ꍇ target Zbg邩ǂB
     *
     * @return tB[h[settargetifnotexist]Ɋi[Ăl
     */
    public boolean getSettargetifnotexist() {
        return fSettargetifnotexist;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.util.task.valueobject.BlancoXliffUtilChangeProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",targetfile=" + fTargetfile);
        buf.append(",sourcefile=" + fSourcefile);
        buf.append(",settargetifnotexist=" + fSettargetifnotexist);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoNLpackGenerator-0.0.97-src.zip: src/blanco/xliff/util/task/valueobject/BlancoXliffUtilChangeProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.util.task.valueobject;

/**
 * NX [BlancoXliffUtilChangeProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoXliffUtilChangeProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [xliffdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * XLIFF (*.xlf) fBNg
     */
    private String fXliffdir;

    /**
     * tB[h [settargetifnotexist]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * target ꍇ target Zbg邩ǂB
     */
    private boolean fSettargetifnotexist = false;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [xliffdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * XLIFF (*.xlf) fBNg
     *
     * @param argXliffdir tB[h[xliffdir]Ɋi[l
     */
    public void setXliffdir(final String argXliffdir) {
        fXliffdir = argXliffdir;
    }

    /**
     * tB[h[xliffdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * XLIFF (*.xlf) fBNg
     *
     * @return tB[h[xliffdir]Ɋi[Ăl
     */
    public String getXliffdir() {
        return fXliffdir;
    }

    /**
     * tB[h [settargetifnotexist]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * target ꍇ target Zbg邩ǂB
     *
     * @param argSettargetifnotexist tB[h[settargetifnotexist]Ɋi[l
     */
    public void setSettargetifnotexist(final boolean argSettargetifnotexist) {
        fSettargetifnotexist = argSettargetifnotexist;
    }

    /**
     * tB[h[settargetifnotexist]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * target ꍇ target Zbg邩ǂB
     *
     * @return tB[h[settargetifnotexist]Ɋi[Ăl
     */
    public boolean getSettargetifnotexist() {
        return fSettargetifnotexist;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.util.task.valueobject.BlancoXliffUtilChangeProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",xliffdir=" + fXliffdir);
        buf.append(",settargetifnotexist=" + fSettargetifnotexist);
        buf.append("]");
        return buf.toString();
    }
}
